Enum solstice_2d::Projection [−][src]
pub enum Projection {
Orthographic(Option<Orthographic>),
Perspective(Option<Perspective>),
}Expand description
A None value means we will use the default projections of the given type
Variants
Orthographic(Option<Orthographic>)
Tuple Fields
0: Option<Orthographic>Perspective(Option<Perspective>)
Tuple Fields
0: Option<Perspective>Trait Implementations
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.