Struct solstice_2d::PerlinTextureSettings [−][src]
pub struct PerlinTextureSettings {
pub seed: i32,
pub width: usize,
pub height: usize,
pub period: u32,
pub levels: u32,
pub attenuation: NotNan<f32>,
pub color: bool,
}Fields
seed: i32width: usizeheight: usizeperiod: u32levels: u32attenuation: NotNan<f32>color: boolTrait Implementations
Returns the “default value” for a type. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more